==> ofxtools-0.8.13.tar.gz: ofxtools-0.8.13/ofxtools/scripts/update_fi_cfg.py <==
#!/usr/bin/env python
# coding: utf-8
"""
Perform an OFX profile scan for the entire OFX Home list of FIs;
update config/fi.cfg

You probably don't want to run this script; it's for the library developers.

It takes a long time to run and generates lots of HTTP requests, and the output
is not at all stable so it needs to be checked.
"""


# stdlib imports
import configparser
from configparser import ConfigParser
from collections import ChainMap
from xml.sax import saxutils
from typing import Mapping, Optional


# local imports
from ofxtools import ofxhome
from ofxtools.scripts import ofxget


LibraryConfig = ConfigParser()
LibraryConfig.read(ofxget.CONFIGPATH)

if not LibraryConfig.has_section("NAMES"):
    LibraryConfig["NAMES"] = {}

# Map ofxhome_id: server_nick for all configs in library
known_servers = {LibraryConfig[sct]["ofxhome"]: sct for sct in LibraryConfig
                 if "ofxhome" in LibraryConfig[sct]}


def mk_server_cfg(args: ofxget.ArgType) -> configparser.SectionProxy:
    """
    Modified version of ofxget.mk_server_cfg()
    """
    server = args["server"]
    assert server

    if not LibraryConfig.has_section(server):
        LibraryConfig[server] = {}
    cfg = LibraryConfig[server]

    for opt in ("url", "version", "ofxhome", "org", "fid", "brokerid",
                "bankid", "pretty", "unclosedelements"):
        if opt in args:
            value = args[opt]
            default_value = ofxget.DEFAULTS[opt]
            if value != default_value and value not in ofxget.NULL_ARGS:
                cfg[opt] = ofxget.arg2config(opt, value)

    return cfg


def write_config(args: ofxget.ArgType) -> None:
    """
    Modified version of ofxget.write_config()
    """
    mk_server_cfg(args)

    with open(ofxget.CONFIGPATH, "w") as f:
        LibraryConfig.write(f)


def main():
    fis: Mapping[str, str] = ofxhome.list_institutions()
    for ofxhome_id in fis.keys():
        print("Scanning {}".format(ofxhome_id))

        lookup: Optional[ofxhome.OFXServer] = ofxhome.lookup(ofxhome_id)
        if lookup is None or lookup.url is None:
            continue

        url = lookup.url
        org = lookup.org
        fid = lookup.fid

        lookup_name = saxutils.unescape(lookup.name)
        srvr_nick = known_servers.get(ofxhome_id, lookup_name)

        ofxhome_id = lookup.id
        assert ofxhome_id
        names = LibraryConfig["NAMES"]
        if ofxhome_id not in names:
            names[ofxhome_id] = lookup_name

        if ofxhome.ofx_invalid(lookup) or ofxhome.ssl_invalid(lookup):
            blank_fmt = {"versions": [], "formats": {}}
            scan_results = (blank_fmt, blank_fmt, {})
        else:
            scan_results: ofxget.ScanResults = ofxget._scan_profile(
                url=url, org=org, fid=fid, timeout=10.0
            )

        v1, v2, _ = scan_results
        if (not v2["versions"]) and (not v1["versions"]):
            # If no OFX response, blank the server config
            LibraryConfig[srvr_nick] = {"ofxhome": ofxhome_id}
            continue

        format = ofxget._best_scan_format(scan_results)

        looked_up_data = {"ofxhome": ofxhome_id,
                          "url": url,
                          "org": org,
                          "fid": fid,
                          "brokerid": lookup.brokerid}

        args = ChainMap({"server": srvr_nick}, looked_up_data, format)
        write_config(args)


if __name__ == "__main__":
    main()

==> ofxtools-0.8.15.tar.gz: ofxtools-0.8.15/ofxtools/scripts/update_fi_cfg.py <==
#!/usr/bin/env python
# coding: utf-8
"""
Perform an OFX profile scan for the entire OFX Home list of FIs;
update config/fi.cfg

You probably don't want to run this script; it's for the library developers.

It takes a long time to run and generates lots of HTTP requests, and the output
is not at all stable so it needs to be checked.
"""


# stdlib imports
import configparser
from configparser import ConfigParser
from collections import ChainMap
from xml.sax import saxutils
from typing import Mapping, Optional


# local imports
from ofxtools import ofxhome
from ofxtools.scripts import ofxget


LibraryConfig = ConfigParser()
LibraryConfig.read(ofxget.CONFIGPATH)

if not LibraryConfig.has_section("NAMES"):
    LibraryConfig["NAMES"] = {}

# Map ofxhome_id: server_nick for all configs in library
known_servers = {
    LibraryConfig[sct]["ofxhome"]: sct
    for sct in LibraryConfig
    if "ofxhome" in LibraryConfig[sct]
}


def mk_server_cfg(args: ofxget.ArgsType) -> configparser.SectionProxy:
    """
    Stripped-down version of ofxget.mk_server_cfg()
    """
    server = args["server"]
    assert server

    if not LibraryConfig.has_section(server):
        LibraryConfig[server] = {}
    cfg = LibraryConfig[server]

    for opt, opt_type in ofxget.CONFIGURABLE_SRVR.items():
        if opt in args:
            value = args[opt]
            default_value = ofxget.DEFAULTS[opt]
            if value != default_value and value not in ofxget.NULL_ARGS:
                cfg[opt] = ofxget.arg2config(opt, opt_type, value)

    return cfg


def write_config(args: ofxget.ArgsType) -> None:
    """
    Modified version of ofxget.write_config()
    """
    mk_server_cfg(args)

    with open(ofxget.CONFIGPATH, "w") as f:
        LibraryConfig.write(f)


def main():
    fis: Mapping[str, str] = ofxhome.list_institutions()
    for ofxhome_id in fis.keys():
        print("Scanning {}".format(ofxhome_id))

        lookup: Optional[ofxhome.OFXServer] = ofxhome.lookup(ofxhome_id)
        if lookup is None or lookup.url is None:
            continue

        url = lookup.url
        org = lookup.org
        fid = lookup.fid

        lookup_name = saxutils.unescape(lookup.name)
        srvr_nick = known_servers.get(ofxhome_id, lookup_name)

        ofxhome_id = lookup.id
        assert ofxhome_id
        names = LibraryConfig["NAMES"]
        if ofxhome_id not in names:
            names[ofxhome_id] = lookup_name

        if ofxhome.ofx_invalid(lookup) or ofxhome.ssl_invalid(lookup):
            blank_fmt = {"versions": [], "formats": {}}
            scan_results = (blank_fmt, blank_fmt, {})
        else:
            scan_results: ofxget.ScanResults = ofxget._scan_profile(
                url=url, org=org, fid=fid, timeout=10.0
            )

        v1, v2, _ = scan_results
        if (not v2["versions"]) and (not v1["versions"]):
            # If no OFX response, blank the server config
            LibraryConfig[srvr_nick] = {"ofxhome": ofxhome_id}
            continue

        format = ofxget._best_scan_format(scan_results)

        looked_up_data = {
            "ofxhome": ofxhome_id,
            "url": url,
            "org": org,
            "fid": fid,
            "brokerid": lookup.brokerid,
        }

        args = ChainMap({"server": srvr_nick}, looked_up_data, format)
        write_config(args)


if __name__ == "__main__":
    main()
